@@ -512,6 +512,8 @@ class MlTrainingSetPreparer:
         @param mode: the cadence mode [short|long]
         """
         flatten_dir = root_dir + "/" + mode
+        if not os.path.exists(flatten_dir):
+            os.mkdir(flatten_dir)
         positive_dir = root_dir + "/tp"
         false_positive_dir = root_dir + "/fp"
         negative_dir = root_dir + "/ntp"
@@ -522,7 +524,7 @@ class MlTrainingSetPreparer:
             dst = flatten_dir + "/" + file
             if os.path.exists(src + "/periodogram_" + mode + ".csv") and \
                     os.path.exists(src + "/time_series_" + mode + ".csv"):
-                os.symlink(src, dst, True)
+                os.symlink(src, dst)
                 with open(dst + "/score.txt", 'w') as the_file:
                     the_file.write(str(1))
         logging.info("Flattening negative dir %s", negative_dir)
